import cdk = require('@aws-cdk/cdk');
import codepipeline = require('@aws-cdk/aws-codepipeline');
import codepipelineapi = require('@aws-cdk/aws-codepipeline-api');
import codecommit = require('@aws-cdk/aws-codecommit');
interface IBuilder {
}
declare class Builder implements IBuilder {
}
export declare type StackCallback = (stackBuilder: StackBuilder) => void;
export declare type ConstructCallback<T extends FluentConstruct> = (constructBuilder: ConstructBuilder<T>, construct: T) => any;
export interface IFluentStackProps extends cdk.StackProps {
    tags?: cdk.Tag[];
}
export declare class FluentStackProps implements IFluentStackProps {
    env?: any;
    namingScheme?: any;
    name?: string;
    tags?: cdk.Tag[];
}
export interface IHash<T> {
    [details: string]: T;
}
export declare class ConstructStore implements IHash<any> {
    SharedResources: IHash<any>;
    setSharedConstruct<T>(name: string, instance: T): void;
    getSharedConstruct<T>(constructName: string): T;
    throwError(exception: string, errorDetail: string): void;
}
export declare class MasterBuilder extends Builder {
    parent: cdk.App;
    stackPrefix: string;
    constructStore: ConstructStore;
    constructReturnValues: Map<string, cdk.IConstruct>;
    pipelines: codepipeline.Pipeline[];
    cicdStack: cdk.Stack;
    synthesisedApps: SynthesisedAppsStore;
    constructor(parent: cdk.App, prefix?: string, appendPrefixSeparator?: boolean);
    withCiCd(cicdPipeLineName: string, repositoryName: string, createNewRepo?: boolean): MasterBuilder;
    addStack(name: string, callStackBuilder: StackCallback, props?: IFluentStackProps): MasterBuilder;
    addCICDStack(name: string, callStackBuilder: StackCallback, props?: IFluentStackProps): MasterBuilder;
    _addstack(name: string, callStackBuilder: StackCallback, props?: IFluentStackProps): MasterBuilder;
    _constructStackName(name: string): any;
}
export declare class StackBuilder extends Builder {
    stack: cdk.Stack;
    masterBuilder: MasterBuilder;
    constructStore: ConstructStore;
    constructor(masterBuilder: MasterBuilder, stack: cdk.Stack);
    addConstruct<T extends FluentConstruct, T2 extends IFluentStackProps>(type: {
        new (parent: cdk.Stack, appName: string, props: T2, constructStore: ConstructStore): T;
    }, name: string, props: T2, addConstructCallback?: ConstructCallback<T>): StackBuilder;
    GetImportValue(name: string): cdk.IConstruct | undefined;
}
export declare class ConstructBuilder<TConstruct extends FluentConstruct> extends Builder {
    parent: StackBuilder;
    construct: TConstruct;
    constructStore: ConstructStore;
    constructor(construct: TConstruct);
    addTag(key: string, value: string): void;
}
export declare class FluentConstruct extends cdk.Construct {
    ConstructStore: ConstructStore;
    Props: IFluentStackProps;
    Prefix: string;
    constructReturnValues: Map<string, cdk.IConstruct>;
    constructor(parent: cdk.Construct, name: string, props: IFluentStackProps, constructStore: ConstructStore);
    StoreOutput(name: string, value: cdk.IConstruct): any;
}
export declare class CICDProps extends FluentStackProps {
    CICDPipeLineName: string;
    RepositoryName: string;
    CreateNewRepo: boolean;
}
export declare class SynthesisedAppsStore implements IHash<any> {
    [details: string]: codepipelineapi.Artifact;
}
export declare class CICD extends FluentConstruct {
    parent: cdk.Stack;
    deployStage: any;
    synthesizedApps: SynthesisedAppsStore;
    pipelines: codepipeline.Pipeline[];
    props: CICDProps;
    constructor(parent: cdk.Stack, name: string, props: CICDProps, constructStore: ConstructStore);
    constructPipeline(repository: codecommit.Repository, branchName: string): codepipeline.Pipeline;
}
export {};
